# `example`

**Usage**:

```console
$ example [OPTIONS]
```

**Options**:

* `--other-arg TEXT`: [default: other_arg]
* `--config-path TEXT`: [default: example.yaml]
* `--num-layers INTEGER`: Number of layers. Maps to 'num_layers'
* `--num-units INTEGER`: Number of units. Maps to 'num_units'
* `--activation TEXT`: Activation function. Maps to 'activation'
* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.
